==> cscec5b-rmat-api-3.0.1-20221021.093018-17-sources.jar: com/ejianc/business/rmat/vo/ExitGFVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * 推送供方
 * 
 * @author syj
 * 
 */
public class ExitGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private String applyId;//申请单主键
    private String billCode; // 单据编号
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String orgId; // 组织
    private String orgName; // 组织名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private String supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String exitDate; // 退场日期
    private String exitNote; // 退场说明
    private String linkName; // 联系人名称
    private String linkTelephone; // 联系人电话
    private Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    private String pkCreator;
    private String creatorName;
    private String creatorDate;
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private String sysmark;
    private List<ExitDetailGFVO> exitDetailList = new ArrayList<>(); // 退场单明细

    public Integer getConfirmFlag() {
        return confirmFlag;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public void setConfirmFlag(Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }

    public String getLinkName() {
        return linkName;
    }

    public void setLinkName(String linkName) {
        this.linkName = linkName;
    }

    public String getLinkTelephone() {
        return linkTelephone;
    }

    public void setLinkTelephone(String linkTelephone) {
        this.linkTelephone = linkTelephone;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getApplyId() {
        return applyId;
    }

    public void setApplyId(String applyId) {
        this.applyId = applyId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitNote() {
        return exitNote;
    }

    public void setExitNote(String exitNote) {
        this.exitNote = exitNote;
    }

    public List<ExitDetailGFVO> getExitDetailList() {
        return exitDetailList;
    }

    public void setExitDetailList(List<ExitDetailGFVO> exitDetailList) {
        this.exitDetailList = exitDetailList;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }
}

==> cscec5b-rmat-api-3.0.1-20230712.113245-230-sources.jar: com/ejianc/business/rmat/vo/ExitGFVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * 推送供方
 * 
 * @author syj
 * 
 */
public class ExitGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private Long applyId;//申请单主键
    private String billCode; // 单据编号
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String orgId; // 组织
    private String orgName; // 组织名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private String supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String exitDate; // 退场日期
    private String exitNote; // 退场说明
    private String linkName; // 联系人名称
    private String linkTelephone; // 联系人电话
    private Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    private String pkCreator;
    private String creatorName;
    private String creatorDate;
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private String sysmark;
    private List<ExitDetailGFVO> exitDetailList = new ArrayList<>(); // 退场单明细

    public Integer getConfirmFlag() {
        return confirmFlag;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public void setConfirmFlag(Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }

    public String getLinkName() {
        return linkName;
    }

    public void setLinkName(String linkName) {
        this.linkName = linkName;
    }

    public String getLinkTelephone() {
        return linkTelephone;
    }

    public void setLinkTelephone(String linkTelephone) {
        this.linkTelephone = linkTelephone;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitNote() {
        return exitNote;
    }

    public void setExitNote(String exitNote) {
        this.exitNote = exitNote;
    }

    public List<ExitDetailGFVO> getExitDetailList() {
        return exitDetailList;
    }

    public void setExitDetailList(List<ExitDetailGFVO> exitDetailList) {
        this.exitDetailList = exitDetailList;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }
}
